==================
Sample Policy File
==================

The following is a sample blazar policy file for adaptation and use.

The sample policy can also be viewed in :download:`file form
</_static/blazar.policy.yaml.sample>`.

.. important::

   The sample policy file is auto-generated from blazar when this
   documentation is built. You must ensure your version of blazar matches
   the version of this documentation.

.. literalinclude:: /_static/blazar.policy.yaml.sample